@@ -11,6 +11,8 @@
 #include "sprite.h"
 #include "interrupt.h"
 
+#include "fixed.h"
+
 extern const unsigned char intro_planet_Bitmap[7680];
 extern const unsigned short intro_planet_Palette[256];
 extern const unsigned char font_Bitmap[4096];
@@ -32,6 +34,10 @@ typedef struct {
 	playership* ship;
 	alien* aliens;
 	u32 num_aliens;
+
+	alien_bullet* alien_bullets;
+	u32 alien_bullets_num;
+
 	u16* charMap;
 } game;
 
@@ -39,6 +45,7 @@ playership* playership_new();
 void playership_read_keys(playership* ship, u32 keys);
 void playership_draw(game* g);
 
+alien_bullet* aliens_create_bullets(int num);
 void aliens_create_wave_blue(alien* aliens, int num);
 void aliens_create_wave_purple(alien* aliens, int num);
 void aliens_free_wave(alien* aliens, int num);
